/*
 * lf3toppm.c
 * Convert LEAF LF3 image to PPM image.
 * 02/05/2000 by TF <tf@imou.to>
 */
#include <stdio.h>
#include <stdlib.h>

#include "lf3.h"

#define TRUE 0
#define FALSE 1

int trans_r, trans_g, trans_b;
int trans_use;

static void output_ppm(LF3 *);
static void usage_exit(void);

int main(int argc, char *argv[])
{
  LF3 *LF3;
  int i;
  char *filename;

  for (i = 1; i < argc; i++) {
    if (!strcmp(argv[i], "-help")) {
      usage_exit();
    } else {
      filename = argv[i];
    }
  }
  
  fprintf(stderr, "Extracting LF3 data...");
  LF3 = read_lf3(filename);
  fprintf(stderr, "done.\n");

  if (LF3 == NULL) {
    fprintf(stderr, "Aborted.\n");
    exit(1);
  }
  
  fprintf(stderr, "Output PPM...");
  output_ppm(LF3);
  fprintf(stderr, "done.\n");
  
  return 0;
}

static void usage_exit(void) {
  fprintf(stderr, "Usage: LF3toppm [-trans color] input.LF3\n");
  exit(1);
}

static void output_ppm(LF3 *LF3)
{
  int i, j;
  int r, g, b;
  int idx;
  
  printf("P6\n");
  printf("# CREATOR: LEAF LF3 decoder\n");
  printf("%d %d\n",
	 LF3->width, LF3->height);
	 
  printf("255\n");
  
  /* GGGB BBBB 0RRR RRGG */

  for (i = LF3->height - 1; i >= 0; i--) {
    for (j = 0; j < LF3->width; j++) {
      idx = LF3->width * 2 * i + j * 2;
      b = (LF3->image[idx] & 0x1f);
      g = ((LF3->image[idx] & 0xe0) >> 5) | ((LF3->image[idx + 1] & 0x03) << 3);
      r = (LF3->image[idx + 1] & 0x7c) >> 2;
      putchar(r << 3);
      putchar(g << 3);
      putchar(b << 3);
    }
  }
}
/* end of file */
